@@ -27,9 +27,9 @@
 #include "disk-io.h"
 #include "print-tree.h"
 #include "transaction.h"
-#include "list.h"
-#include "utils.h"
-#include "help.h"
+#include "kernel-lib/list.h"
+#include "common/utils.h"
+#include "common/help.h"
 
 #define BUFFER_SIZE SZ_64K
 
@@ -252,7 +252,7 @@ int main(int argc, char **argv)
 	}
 	set_argv0(argv);
 	if (check_argc_min(argc - optind, 1))
-		print_usage();
+		return 1;
 	if (logical == 0)
 		print_usage();
 
